stdlib

package
v0.0.0-...-6224849 Latest Latest
Warning

This package is not in the latest version of its module.

Go to latest
Published: Apr 6, 2026 License: MIT Imports: 4 Imported by: 0

Documentation

Index

Constants

const Version = "0.2"

Variables

This section is empty.

Functions

func NewResolver

func NewResolver(fallback modules.Resolver) modules.Resolver

NewResolver wraps a fallback resolver with the embedded stdlib registry.

func Paths

func Paths() []string

Paths returns the embedded stdlib module paths.

func Source

func Source(path string) ([]byte, error)

Source returns embedded stdlib source by canonical module path.

Types

type Resolver

type Resolver struct {
	Fallback modules.Resolver
}

Resolver resolves embedded stdlib modules first, then falls back to the provided filesystem resolver.

func (Resolver) Resolve

func (r Resolver) Resolve(path string) ([]byte, error)

Jump to